#define _CRT_SECURE_NO_WARNINGS

#include <stdio.h>
#include <stdlib.h>
#include <iostream>
#include <algorithm>
#include <math.h>
using namespace std;

struct node
{
	node *left, *right;
	int value;
	int children;	
};

int getChildrenCount(node* node)
{
	return node == NULL ? 0 : node->children;
}

void updateChildrenCount(node* node)
{
	if (node == NULL) return;

	node->children = getChildrenCount(node->left) + getChildrenCount(node->right) + 1;
}

node data[200000];
int busy;

node* getnode(int value)
{
	node* res = &(data[busy]);
	res->left = res->right = NULL;
	res->value = value;
	res->children = 0;
	busy++;
	return res;
}

class splay_tree
{
	node* root;

	node* splay(node* cur, int value)
	{
		if (cur == NULL) return NULL;

		if (value == cur->value) return cur;

		if (value < cur->value) 
		{
			if (cur->left == NULL) 
			{
				return cur;
			}
			
			if (value < cur->left->value) {
				cur->left->left = splay(cur->left->left, value);
				cur = rotate_right(cur);
			}
			else if (value > cur->left->value)
			{
				cur->left->right = splay(cur->left->right, value);
				if (cur->left->right != NULL)
				{
					cur->left = rotate_left(cur->left);
				}
			}

			if (cur->left == NULL)
			{
				return cur;
			}
			else
			{
				return rotate_right(cur);
			}
		}
		else if (value > cur->value) 
		{
			
			if (cur->right == NULL) 
			{
				return cur;
			}
			
			if (value < cur->right->value) 
			{
				cur->right->left = splay(cur->right->left, value);
				if (cur->right->left != NULL)
				{
					cur->right = rotate_right(cur->right);
				}
			}
			else if (value > cur->right->value)
			{
				cur->right->right = splay(cur->right->right, value);
				cur = rotate_left(cur);
			}

			if (cur->right == NULL)
			{
				return cur;
			}
			else
			{
				return rotate_left(cur);
			}
		}			
	}

	node* rotate_right(node* cur) 
	{
		node* lchild = cur->left;
		cur->left = lchild->right;
		lchild->right = cur;
		
		updateChildrenCount(cur->left);
		updateChildrenCount(cur->right);
		updateChildrenCount(cur);

		return lchild;
	}

	node* rotate_left(node* cur)
	{
		node* rchild = cur->right;
		cur->right = rchild->left;
		rchild->left = cur;

		updateChildrenCount(cur->left);
		updateChildrenCount(cur->right);
		updateChildrenCount(cur);

		return rchild;
	}
public:
	splay_tree() : root(NULL)
	{
	}

	void insert(int value)
	{
		if (root == NULL)
		{
			root = getnode(value);			
			root->children = 1;
			return;
		}
		
		root = splay(root, value);

		if (value < root->value)
		{
			node* n = getnode(value);
			n->left = root->left;
			n->right = root;
			root->left = NULL;
			root = n;
		}
		else if (value > root->value)
		{
			node* n = getnode(value);
			n->right = root->right;
			n->left = root;
			root->right = NULL;			
			root = n;
		}

		updateChildrenCount(root->left);
		updateChildrenCount(root->right);
		updateChildrenCount(root);
	}

	void remove(int value)
	{
		root = splay(root, value);

		if (root->left == NULL)
		{
			root = root->right;
		}
		else
		{
			node* r = root->right;
			root = splay(root->left, root->value);
			root->right = r;
		}
	}

	node* find(int value)
	{
		root = splay(root, value);

		return root;
	}
};



int main()
{
	freopen("code.in", "r", stdin);
	freopen("code.out", "w", stdout);

	int a[100000];

	int test;
	cin >> test;
	for (int t = 0; t < test; t++)
	{
		busy = 0;
		splay_tree tree;

		int n;
		cin >> n;
		
		for (int i = 0; i < n; i++)
		{
			cin >> a[i];
			tree.insert(a[i]);
		}

		for (int i = 0; i < n; i++)
		{
			node* node = tree.find(a[i]);
			cout << getChildrenCount(node->left);
			if (i != n - 1) cout << ' ';
			tree.remove(a[i]);
		}

		cout << endl;

	}

	return 0;
}
