//Author's solution of the problem "Cycle"

#include <set>
#include <queue>
#include <ctime>
#include <vector>
#include <cassert>
#include <fstream>
#include <iterator>
#include <iostream>
#include <algorithm>

const int NOPE = -1;

int BFS(const std::vector<std::vector<int> > & adj, int start, int end, const std::vector<std::pair<int, int> > & deprecate)
{
	std::queue<int> q;
	std::vector<int> d(adj.size(), NOPE);
	q.push(start);
	d[start] = 0;
	while(!q.empty())
	{
		int u = q.front();
		q.pop();
		for(int j = 0; j < adj[u].size(); j++)
		{
			int v = adj[u][j];
			std::pair<int, int> e(u, v);
			if(d[v] == NOPE && std::find(deprecate.begin(), deprecate.end(), e) == deprecate.end())
			{
				q.push(v);
				d[v] = d[u] + 1;
			}
		}
	}

	return d[end];
}

int Girth(const std::vector<std::vector<int> > & adj)
{
	int res = 1 << 20;
	std::vector<std::pair<int, int> > deprecate;
	for(int u = 0; u < adj.size(); u++)
	{
		for(int j = 0; j < adj[u].size(); j++)
		{
			int v = adj[u][j];
			deprecate.clear();
			deprecate.push_back(std::make_pair(u, v));
			deprecate.push_back(std::make_pair(v, u));
			int length = BFS(adj, u, v, deprecate);
			if(length != NOPE)
			{
				res = std::min(res, length + 1);					
			}
		}
	}
	
	return res;
}

bool PresentEdge(std::set<std::pair<int, int> > & edge, int u, int v)
{
	std::pair<int, int> uv(u, v);
	std::pair<int, int> vu(v, u);
	return edge.find(uv) != edge.end() || edge.find(vu) != edge.end();
}

void GenerateTest(std::ostream & out, int n, int m, int girth)
{
	std::vector<int> p(n);
	for(int i = 0; i < p.size(); i++)
	{
		p[i] = i;
	}

	std::set<std::pair<int, int> > edge;
	std::random_shuffle(p.begin(), p.end());
	for(int i = 0; i <= n - girth; )
	{
		int length = i == 0 ? girth : girth + rand() % (n - girth - i);
		for(size_t j = 0; j < length; j++)
		{
			edge.insert(std::make_pair(p[i + j], p[i + (j + 1) % length]));
		}

		i += length;
	}

	std::vector<std::pair<int, int> > cand;
	for(int i = 0; i < n; i++)
	{
		for(int j = i + 1; j < n; j++)
		{
			cand.push_back(std::make_pair(p[i], p[j]));
		}
	}
	
	std::random_shuffle(cand.begin(), cand.end());
	for(int j = 0; j < cand.size() && edge.size() < m; j++)
	{
		int u = cand[j].first;
		int v = cand[j].second;
		if(!PresentEdge(edge, u, v))
		{
			std::vector<std::vector<int> > adj(n);
			for(std::set<std::pair<int, int> >::iterator it = edge.begin(); it != edge.end(); ++it)
			{
				adj[it->first].push_back(it->second);
				adj[it->second].push_back(it->first);
			}
			
			adj[u].push_back(v);
			adj[v].push_back(u);

			int newGirth = Girth(adj);				
			if(newGirth == girth)
			{
					edge.insert(std::make_pair(u, v));
			}
		}
	}
	
	for(std::set<std::pair<int, int> >::iterator it = edge.begin(); it != edge.end(); ++it)
	{
		out << it->first + 1 << " " << it->second + 1 << std::endl;
	}		
}

void GenTests()
{
	for(int i = 0; i < 7; i++)
	{
		int n = 200;
		GenerateTest(std::cout, n, 1000, 3 + rand() % (n / 4));
	}

	for(int i = 0; i < 7; i++)
	{
		int n = 200;
		GenerateTest(std::cout, n, 1000, 3 + rand() % 10);
	}
}

int main()
{
	int test;
	std::ifstream in("driving.in");
	std::vector<std::vector<int> > adj;
	for(in >> test; test > 0; --test)
	{
		int n;
		int m;
		in >> n >> m;
		adj.assign(n, std::vector<int>());
		
		int u;
		int v;
		for(int i = 0; i < m; i++)
		{
			in >> u >> v;
			adj[u - 1].push_back(v - 1);
			adj[v - 1].push_back(u - 1);
		}

		std::cout << Girth(adj) << std::endl;
	}

	std::cerr << "Time: " << double(clock()) / 1000 << std::endl;
	return 0;
}