#include <iostream>
#include <fstream>
#include <ctime>
#include <vector>
#include <cassert>
#include <map>
#include <algorithm>
#include <cmath>

using namespace std;

const int MAXT = 6;
const int TW = 3, TH = 2;

// coordinates of the furniture in the office (tables, bookcases)
vector<int> X, Y, W, H;

int N, M, B;
int ans, cur;


int dw[] = {TW, TH};
int dh[] = {TH, TW};

bool ok_dist(int a, int b)
{
	return abs(a - b) >= 1;
}

bool ins(int from, int to, int x)
{
	return x > from && x < to;
}

bool compatible(int xb1, int yb1, int xe1, int ye1, int xb2, int yb2, int xe2, int ye2)
{
	// rect 2 inside 1 (increase size of rect 1 by 1 in all dimensions)

	if (
		(ins(xb1-1, xe1+1, xb2) || ins(xb1-1, xe1+1, xe2)) &&
		(ins(yb1-1, ye1+1, yb2) || ins(yb1-1, ye1+1, ye2))
		)
		return false;

	// rect 1 inside 2 (increase size of rect 2 by 1 in all dimensions)
	if (
		(ins(xb2-1, xe2+1, xb1) || ins(xb2-1, xe2+1, xe1)) &&
		(ins(yb2-1, ye2+1, yb1) || ins(yb2-1, ye2+1, ye1))
		)
		return false;

	return true;
}

// DEBUG: prints current field.
void print(int t)
{
	cout <<endl <<endl;
	vector<vector<char> > V(N, vector<char>(M, '.'));
	for (int i = 0;i < B + t;i++)
		for (int x = X[i];x < X[i] + W[i];x++)
			for (int y = Y[i]; y < Y[i] + H[i];y++)
				V[x][y] = i < B ? '*' : '#';

	for (int i = 0;i < M;i++)
	{
		for (int j = 0;j < N;j++)
			cout <<V[j][i];
		cout <<endl;
	}
	cout <<endl <<endl;

}

void rec(int t)
{
	if (t > MAXT || ans == MAXT)	// we can't place more tables by the statement.
		return;

	ans = max(ans, t);

	for (int p = 0;p < 2;p++)
		for (int x = 1;x < N - dw[p];x++)
			for (int y = 1;y < M - dh[p];y++)
			{
				bool ok = true;
				for (int i = 0;i < B + t;i++)	// check existing objects - tables and bookcases
				{
					if (!compatible(x, y, x + dw[p], y + dh[p], X[i], Y[i], X[i] + W[i], Y[i] + H[i]))
					{
						ok = false;
						break;
					}
				}

				if (ok)
				{
					X[B + t] = x;
					Y[B + t] = y;
					W[B + t] = dw[p];
					H[B + t] = dh[p];
					rec(t + 1);
				}
			}
}

void validate_input()
{
	assert(B >= 0 && B <= 10);
	assert(N >= 1 && N <= 10);
	assert(M >= 1 && M <= 10);

	vector<vector<char> > F(N, vector<char>(M, ' '));
	for (int i = 0;i < B;i++)
	{
		assert(X[i] >= 0 && X[i] < N);
		assert(Y[i] >= 0 && Y[i] < M);
		assert((X[i] + W[i]) <= N && (Y[i] + H[i]) <= M);

		for (int x = X[i];x < X[i] + W[i];x++)
			for (int y = Y[i];y < Y[i] + H[i];y++)
			{
				assert(F[x][y] == ' ');
				F[x][y] = '*';
			}
	}	
}
/*
int rnd(int f, int t)
{
	if (f == t) return f;
	return (rand() % t) + f;
}

void gen_tests()
{
	freopen("c:\\temp\\job.in.gen", "w", stdout);
	srand(21432432);

	for (int cc = 0;cc < 100;cc++)
	{

		N = rnd(1, 10);
		M = rnd(1, 10);
		int b_try;
		
		if (cc < 33)
			b_try = rnd(0, (N*M)/10);
		else if (cc < 90)
			b_try = rnd(0, 3);
		else
			b_try = rnd(4, 15);


		B = 0;
		X = Y = W = H = vector<int>();

		vector<vector<char> > F(N, vector<char>(M, ' '));

		for (int i = 0;i < b_try && B <= 10;i++)
		{
			int x = rnd(0, N-1);
			int y = rnd(0, M-1);
			int w = cc % 2 ? rnd(1, min(2, N-x)) : rnd(1, N-x);
			int h = cc % 2 ? rnd(1, min(2, M-y)) : rnd(1, M-y);

			bool ok = true;
			for (int a = x;a < x + w;a++)
				for (int b = y;b < y + h;b++)
				{
					if (F[a][b] != ' ')
					{
						ok = false;
						goto out;
					}
				}
out:;
			if (ok)
			{
				for (int a = x;a < x + w;a++)
					for (int b = y;b < y + h;b++)
						F[a][b] = '*';
				B++;
				X.push_back(x);
				Y.push_back(y);
				W.push_back(w);
				H.push_back(h);
			}
		}

		validate_input();
		cout <<N << " " <<M << " " <<B <<endl;
		for (int i = 0;i < B;i++)
			cout <<X[i] <<" " <<Y[i] << " " <<W[i] <<" " <<H[i] <<endl;
	}
}
*/

int main(int argc, char *argv[])
{
	//gen_tests();
	//return 0;

	freopen("job.in", "r", stdin);

	int tc;
	cin >>tc;

	for (int cc = 0;cc < tc;cc++)
	{		
		cin >>N >>M >>B;

		X.resize(B + MAXT);
		Y.resize(B + MAXT);
		W.resize(B + MAXT);
		H.resize(B + MAXT);

		ans = cur = 0;

		for (int i = 0;i < B;i++)
			cin >>X[i] >>Y[i]>> W[i] >>H[i];

		validate_input();
		rec(0);
		//cout <<"Case " <<cc + 1 <<": ";
		cout <<ans <<endl;
	}

	return 0;
}
