#include <cstdio>
#include <ctime>
#include <iostream>
#include <fstream>
#include <algorithm>
#include <cassert>
using namespace std;
const int nmax = 1000000000, kmax = 10, mod = 2017;
int v[kmax], n, k;

struct Matrix
{
	int m[kmax][kmax];

	Matrix() {
		for (int i = 0; i < k; i++) {
			for (int j = 0; j < k; j++) {
				this->m[i][j] = 0;
			}
		}
	}

	void setValue(Matrix a) {
		for (int i = 0; i < k; i++) {
			for (int j = 0; j < k; j++) {
				this->m[i][j] = a.m[i][j];
			}
		}
	}
};

Matrix mult(Matrix a, Matrix b)
{
	Matrix res;

	for (int i = 0; i < k; i++) {
		for (int j = 0; j < k; j++) {
			for (int z = 0; z < k; z++) {
				res.m[i][j] = (res.m[i][j] + a.m[i][z] * b.m[z][j]) % mod;
			}
		}
	}

	return res;
}

Matrix pow(Matrix m, int n)
{
	Matrix res;
	for (int i = 0; i < k; i++) {
		for (int j = 0; j < k; j++) {
			res.m[i][j] = i == j ? 1: 0;
		}
	}

	while (n > 0) {
		if (n % 2 == 0) {
			m.setValue(mult(m, m));
			n /= 2;
		}
		else {
			res.setValue(mult(res, m));
			n--;
		}
	}

	return res;
}

int main()
{
	//clock_t tStart = clock();

	ifstream inFile;
	ofstream outFile;
	int tests, i, j, res = 0;

	for (i = 0; i < kmax; i++) {
		v[i] = i == 0 ? 1 : 0;
	}
	
	inFile.open("kohinoor.in");
	outFile.open("kohinoor.out");

	inFile >> tests;
	while (tests > 0) {
		inFile >> n >> k;

		assert(n > 0 && n <= nmax);
		assert(k > 0 && k <= min(n, kmax));

		Matrix m;

		for (i = 0; i < k; i++) {
			for (j = 0; j < k; j++) {
				m.m[i][j] = (i == j ? i + 1 : (i == j - 1 ? 1 : 0));
			}
		}

		if (n == 1) res = 1;
		else
		{
			m.setValue(pow(m, n - 1));

			res = 0;
			for (i = 0; i < k; i++) {
				res = (res + v[i] * m.m[i][k - 1]) % mod;
			}
		}

		outFile << res;
		if(tests > 1) outFile << endl;

		tests--;
	}
	
	//outFile << endl << "Time taken: " <<  (double)(clock() - tStart) / CLOCKS_PER_SEC;

	inFile.close();
	outFile.close();

	return 0;
}